@@ -8,20 +8,14 @@
 
 extern crate core;
 
-// mod css;
 mod macros;
 mod modules;
 mod systems;
 mod traits;
 
 pub use self::{
-    modules::{
-        accessibility::*, background::*, borders::*, effects::*, filters::*, flexbox::*, interactivity::*, layouts::*,
-        sizing::*, spacing::*, tables::*, transforms::*, transition::*, typography::*,
-    },
-    systems::{
-        breakpoints::*, builder::*, colors::*, css_global::*, fonts::*, instruction::*, length::*, preflight::*, processor::*,
-    },
+    modules::*,
+    systems::*,
     traits::{CssAttribute, ParsedItem, ParsedList, TailwindInstance, TailwindObject},
 };
 pub use tailwind_error::{Result, TailwindError, TailwindErrorKind};
