@@ -1,11 +1,14 @@
+use crate::TailwindSizing;
+
+use super::*;
+
+pub use self::{select::TailwindSelect, torch::TailwindTorch};
+
 mod display;
 mod parser;
+mod select;
 mod torch;
 
-pub use self::torch::TailwindTorch;
-use super::*;
-use crate::TailwindSizing;
-
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
 pub struct TailwindAccentColor {}
@@ -46,22 +49,6 @@ pub enum TailwindScroll {}
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindSnap {}
 
-#[derive(Debug, Copy, Clone)]
-enum SelectKind {
-    None,
-    Auto,
-    Text,
-    Contain,
-    All,
-    Global(CssBehavior),
-}
-
-#[doc=include_str!("grid-row.md")]
-#[derive(Debug, Copy, Clone)]
-pub struct TailwindSelect {
-    kind: SelectKind,
-}
-
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindWillChange {}
