@@ -15,34 +15,37 @@ impl TailwindInstruction {
             ["break", rest @ ..] => Self::break_adaptor(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
             // begin https://tailwindcss.com/docs/display
-            ["block"] => TailwindDisplay::Block.boxed(),
-            ["inline", "block"] => TailwindDisplay::InlineBlock.boxed(),
-            ["inline"] => TailwindDisplay::InlineFlex.boxed(),
-            // flex catched
-            ["inline", "flex"] => TailwindDisplay::InlineFlex.boxed(),
-            // table catched
-            ["inline", "table"] => TailwindDisplay::InlineFlex.boxed(),
-            // table catched
-            ["flow", "root"] => TailwindDisplay::InlineFlex.boxed(),
-            // grid catched
-            ["inline", "grid"] => TailwindDisplay::InlineFlex.boxed(),
-            ["contents"] => TailwindDisplay::InlineFlex.boxed(),
-            // list catched
-            ["hidden"] => TailwindDisplay::InlineFlex.boxed(),
+            ["block"] => TailwindDisplay::from("block").boxed(),
+            ["inline", "block"] => TailwindDisplay::from("inline-block").boxed(),
+            ["inline"] => TailwindDisplay::from("inline").boxed(),
+            ["flex"] => TailwindDisplay::from("flex").boxed(),
+            ["inline", "flex"] => TailwindDisplay::from("inline-flex").boxed(),
+            ["table"] => TailwindDisplay::from("table").boxed(),
+            ["inline", "table"] => TailwindDisplay::from("inline-table").boxed(),
+            ["table", "caption"] => TailwindDisplay::from("table-caption").boxed(),
+            ["table", "cell"] => TailwindDisplay::from("table-cell").boxed(),
+            ["table", "column"] => TailwindDisplay::from("table-column").boxed(),
+            ["table", "column", "group"] => TailwindDisplay::from("table-column-group").boxed(),
+            ["table", "footer", "group"] => TailwindDisplay::from("table-footer-group").boxed(),
+            ["table", "header", "group"] => TailwindDisplay::from("table-header-group").boxed(),
+            ["table", "row", "group"] => TailwindDisplay::from("table-row-group").boxed(),
+            ["table", "row"] => TailwindDisplay::from("table-row").boxed(),
+            ["flow", "root"] => TailwindDisplay::from("flow-root").boxed(),
+            ["grid"] => TailwindDisplay::from("grid").boxed(),
+            ["inline", "grid"] => TailwindDisplay::from("inline-grid").boxed(),
+            ["contents"] => TailwindDisplay::from("contents").boxed(),
+            ["list", "item"] => TailwindDisplay::from("inline-grid").boxed(),
+            ["hidden"] => TailwindDisplay::from("hidden").boxed(),
             // https://tailwindcss.com/docs/float
             ["float", rest @ ..] => TailwindFloat::parse(rest, arbitrary)?.boxed(),
             ["clear", rest @ ..] => TailwindClear::parse(rest, arbitrary)?.boxed(),
-            ["isolate"] => TailwindIsolation::Isolate.boxed(),
-            ["isolation", "auto"] => TailwindIsolation::Auto.boxed(),
-            ["object", rest @ ..] => Self::object_adaptor(rest, arbitrary)?,
+            ["isolate"] => TailwindIsolation::from("isolate").boxed(),
+            ["isolation", rest @ ..] => TailwindIsolation::parse(rest, arbitrary)?.boxed(),
+            ["object", rest @ ..] => object_adaptor(rest, arbitrary)?,
             ["overflow", rest @ ..] => Self::overflow_adaptor(rest, arbitrary)?,
             ["overscroll", rest @ ..] => Self::overscroll_adaptor(rest, arbitrary)?,
-            // begin https://tailwindcss.com/docs/position
-            ["static"] => TailwindPosition::Static.boxed(),
-            ["fixed"] => TailwindPosition::Fixed.boxed(),
-            ["absolute"] => TailwindPosition::Absolute.boxed(),
-            ["relative"] => TailwindPosition::Relative.boxed(),
-            ["sticky"] => TailwindPosition::Sticky.boxed(),
+            // https://tailwindcss.com/docs/position#header
+            [s @ ("static" | "fixed" | "absolute" | "relative" | "sticky")] => TailwindPosition::from(*s).boxed(),
             // https://tailwindcss.com/docs/top-right-bottom-left
             ["inset", _rest @ ..] => todo!(),
             ["top", _rest @ ..] => todo!(),
@@ -89,23 +92,23 @@ impl TailwindInstruction {
             ["min", "h", rest @ ..] => TailwindSizing::parse_width_min(rest, arbitrary)?.boxed(),
             ["max", "h", rest @ ..] => TailwindSizing::parse_width_max(rest, arbitrary)?.boxed(),
             // Typography System
-            ["font", rest @ ..] => Self::font_adaptor(rest, arbitrary)?,
-            ["text", rest @ ..] => Self::text_adaptor(rest, arbitrary)?,
+            ["font", rest @ ..] => font_adaptor(rest, arbitrary)?,
+            ["text", rest @ ..] => text_adaptor(rest, arbitrary)?,
             // begin https://tailwindcss.com/docs/font-variant-numeric
-            ["antialiased"] => TailwindFontSmoothing::new(false).boxed(),
-            ["subpixel", "antialiased"] => TailwindFontSmoothing::new(true).boxed(),
-            ["italic"] => TailwindFontStyle::Italic.boxed(),
-            ["not", "italic"] => TailwindFontStyle::Normal.boxed(),
+            ["antialiased"] => TailwindFontSmoothing::from("todo").boxed(),
+            ["subpixel", "antialiased"] => TailwindFontSmoothing::from("todo").boxed(),
+            ["italic"] => TailwindFontStyle::from("italic").boxed(),
+            ["not", "italic"] => TailwindFontStyle::from("normal").boxed(),
             // https://tailwindcss.com/docs/font-variant-numeric
-            ["normal", "nums"] => TailwindFontVariantNumeric::Normal.boxed(),
-            ["ordinal"] => TailwindFontVariantNumeric::Ordinal.boxed(),
-            ["slashed", "zero"] => TailwindFontVariantNumeric::SlashedZero.boxed(),
-            ["lining", "nums"] => TailwindFontVariantNumeric::Lining.boxed(),
-            ["oldstyle", "nums"] => TailwindFontVariantNumeric::OldStyle.boxed(),
-            ["proportional", "nums"] => TailwindFontVariantNumeric::Proportional.boxed(),
-            ["tabular", "nums"] => TailwindFontVariantNumeric::Tabular.boxed(),
-            ["diagonal", "fractions"] => TailwindFontVariantNumeric::DiagonalFractions.boxed(),
-            ["stacked", "fractions"] => TailwindFontVariantNumeric::StackedFractions.boxed(),
+            ["normal", "nums"] => TailwindFontVariantNumeric::from("normal").boxed(),
+            ["ordinal"] => TailwindFontVariantNumeric::from("ordinal").boxed(),
+            ["slashed", "zero"] => TailwindFontVariantNumeric::from("slashed-zero").boxed(),
+            ["lining", "nums"] => TailwindFontVariantNumeric::from("lining-nums").boxed(),
+            ["oldstyle", "nums"] => TailwindFontVariantNumeric::from("oldstyle-nums").boxed(),
+            ["proportional", "nums"] => TailwindFontVariantNumeric::from("proportional-nums").boxed(),
+            ["tabular", "nums"] => TailwindFontVariantNumeric::from("tabular-nums").boxed(),
+            ["diagonal", "fractions"] => TailwindFontVariantNumeric::from("diagonal-fractions").boxed(),
+            ["stacked", "fractions"] => TailwindFontVariantNumeric::from("stacked-fractions").boxed(),
             // https://tailwindcss.com/docs/letter-spacing
             ["tracking", rest @ ..] => TailwindTracking::parse(rest, arbitrary)?.boxed(),
             ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
@@ -119,10 +122,10 @@ impl TailwindInstruction {
             ["decoration", rest @ ..] => TailwindDecoration::parse(rest, arbitrary)?,
             ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/text-transform
-            ["uppercase"] => TailwindTextTransform::Uppercase.boxed(),
-            ["lowercase"] => TailwindTextTransform::Lowercase.boxed(),
-            ["capitalize"] => TailwindTextTransform::Capitalize.boxed(),
-            ["normal", "case"] => TailwindTextTransform::None.boxed(),
+            ["uppercase"] => TailwindTextTransform::from("uppercase").boxed(),
+            ["lowercase"] => TailwindTextTransform::from("lowercase").boxed(),
+            ["capitalize"] => TailwindTextTransform::from("capitalize").boxed(),
+            ["normal", "case"] => TailwindTextTransform::from("none").boxed(),
             // https://tailwindcss.com/docs/text-overflow
             ["truncate"] => TailwindTextOverflow::Truncate.boxed(),
             ["indent", rest @ ..] => TailwindIndent::parse(rest, arbitrary)?.boxed(),
@@ -140,9 +143,9 @@ impl TailwindInstruction {
             ["to", _rest @ ..] => todo!(),
             // Borders System
             ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
-            ["border", rest @ ..] => Self::border_adaptor(rest, arbitrary)?,
+            ["border", rest @ ..] => TailwindBorder::parse(rest, arbitrary)?,
             ["divide", rest @ ..] => Self::divide_adaptor(rest, arbitrary)?,
-            ["outline", rest @ ..] => Self::outline_adaptor(rest, arbitrary)?,
+            ["outline", rest @ ..] => outline_adaptor(rest, arbitrary)?,
             ["ring", rest @ ..] => Self::ring_adaptor(rest, arbitrary)?,
             // Effects System
             ["shadow", rest @ ..] => Self::shadow_adaptor(rest, arbitrary)?,
@@ -152,7 +155,7 @@ impl TailwindInstruction {
             ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, false)?.boxed(),
             ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary, false)?.boxed(),
             ["contrast", rest @ ..] => TailwindContrast::parse(rest, arbitrary, false)?.boxed(),
-            ["drop", "shadow", rest @ ..] => TailwindShadow::parse_drop(rest, arbitrary)?.boxed(),
+            ["drop", "shadow", rest @ ..] => TailwindShadow::parse(rest, arbitrary, true)?.boxed(),
             ["grayscale", rest @ ..] => TailwindGrayscale::parse(rest, arbitrary, false)?.boxed(),
             ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, false)?.boxed(),
             ["invert", rest @ ..] => TailwindInvert::parse(rest, arbitrary, false)?.boxed(),
@@ -202,18 +205,18 @@ impl TailwindInstruction {
         Ok(instance)
     }
     #[inline]
-    fn break_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn break_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/border-style
             ["normal"] => TailwindBreak::Normal.boxed(),
             ["words"] => TailwindBreak::Words.boxed(),
             ["all"] => TailwindBreak::All.boxed(),
             // https://tailwindcss.com/docs/break-before
-            ["before", rest @ ..] => TailwindBreakLayout::parse_before(rest)?.boxed(),
+            ["before", rest @ ..] => TailwindBreakBefore::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/break-inside
-            ["inside", rest @ ..] => TailwindBreakLayout::parse_inside(rest)?.boxed(),
+            ["inside", rest @ ..] => TailwindBreakInside::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/break-after
-            ["after", rest @ ..] => TailwindBreakLayout::parse_after(rest)?.boxed(),
+            ["after", rest @ ..] => TailwindBreakAfter::parse(rest, arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown break instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -251,33 +254,7 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn border_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // border
-            // [] => TailwindBorderWidth::parse(),
 
-            // https://tailwindcss.com/docs/border-style
-            ["solid"] => TailwindBorderStyle::Solid.boxed(),
-            ["dashed"] => TailwindBorderStyle::Dashed.boxed(),
-            ["dotted"] => TailwindBorderStyle::Dotted.boxed(),
-            ["double"] => TailwindBorderStyle::Double.boxed(),
-            ["hidden"] => TailwindBorderStyle::Hidden.boxed(),
-            ["none"] => TailwindBorderStyle::None.boxed(),
-            // https://tailwindcss.com/docs/border-collapse
-            ["collapse"] => TailwindBorderCollapse::Collapse.into_instance(),
-            ["separate"] => TailwindBorderCollapse::Separate.into_instance(),
-            // https://tailwindcss.com/docs/border-color
-            ["inherit"] => TailwindBorderCollapse::Collapse.into_instance(),
-            ["current"] => TailwindBorderCollapse::Separate.into_instance(),
-            ["transparent"] => TailwindBorderCollapse::Separate.into_instance(),
-            ["black"] => TailwindBorderCollapse::Separate.into_instance(),
-            ["white"] => TailwindBorderCollapse::Separate.into_instance(),
-
-            _ => return syntax_error!("Unknown border instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
     #[inline]
     fn divide_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
@@ -287,35 +264,13 @@ impl TailwindInstruction {
             ["y"] => todo!(),
             ["y", _n] => todo!(),
             // https://tailwindcss.com/docs/divide-style
-            ["solid"] => TailwindDivideStyle::Solid.boxed(),
-            ["dashed"] => TailwindDivideStyle::Dashed.boxed(),
-            ["dotted"] => TailwindDivideStyle::Dotted.boxed(),
-            ["double"] => TailwindDivideStyle::Double.boxed(),
-            ["none"] => TailwindDivideStyle::None.boxed(),
+            [s @ ("solid" | "dashed" | "dotted" | "double" | "none")] => TailwindDivideStyle::from(*s).boxed(),
             // https://tailwindcss.com/docs/divide-color
             _ => return syntax_error!("Unknown divide instructions: {}", str.join("-")),
         };
         Ok(out)
     }
     #[inline]
-    fn outline_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/outline-style
-            [] => todo!(),
-            ["none"] => TailwindOutlineStyle::None.boxed(),
-            ["dashed"] => TailwindOutlineStyle::Dashed.boxed(),
-            ["dotted"] => TailwindOutlineStyle::Dotted.boxed(),
-            ["double"] => TailwindOutlineStyle::Double.boxed(),
-            ["hidden"] => TailwindOutlineStyle::Hidden.boxed(),
-            // https://tailwindcss.com/docs/outline-offset
-            ["offset", _n] => todo!(),
-            // https://tailwindcss.com/docs/outline-width
-            [_n] => todo!(),
-            _ => return syntax_error!("Unknown outline instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
-    #[inline]
     fn ring_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/ring-offset-width
@@ -328,20 +283,19 @@ impl TailwindInstruction {
     fn shadow_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/box-shadow
-            [] => TailwindShadow::parse_arbitrary(arbitrary)?.boxed(),
+            [] => todo!(),
             ["sm"] => todo!(),
             // https://tailwindcss.com/docs/box-shadow-color
-            _ => return syntax_error!("Unknown shadow instructions: {}", str.join("-")),
+            _ => TailwindShadow::parse(str, arbitrary, false)?.boxed(),
         };
         Ok(out)
     }
     #[inline]
-    fn box_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn box_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            ["decoration", "clone"] => TailwindBoxDecoration::Clone.boxed(),
-            ["decoration", "slice"] => TailwindBoxDecoration::Slice.boxed(),
-            ["border"] => TailwindBoxSizing::Border.boxed(),
-            ["content"] => TailwindBoxSizing::Content.boxed(),
+            ["decoration", rest @ ..] => TailwindBoxDecoration::parse(rest, arbitrary)?.boxed(),
+            ["border"] => TailwindBoxSizing::from("border").boxed(),
+            ["content"] => TailwindBoxSizing::from("content").boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -350,7 +304,7 @@ impl TailwindInstruction {
     fn flex_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/display#flex
-            [] if arbitrary.is_none() => TailwindDisplay::Flex.boxed(),
+            // `[]` => This won't happen
             // https://tailwindcss.com/docs/flex#arbitrary-values
             [] => TailwindFlex::parse_arbitrary(arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/flex-direction
@@ -463,33 +417,19 @@ impl TailwindInstruction {
     #[inline]
     fn table_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
+            // https://tailwindcss.com/docs/display#flex
+            // `[]` => This won't happen
             ["caption"] => TailwindTableLayout::Auto.boxed(),
             ["right"] => TailwindTableLayout::Auto.boxed(),
             ["none"] => TailwindTableLayout::Auto.boxed(),
             // https://tailwindcss.com/docs/table-layout
             ["auto"] => TailwindTableLayout::Auto.boxed(),
             ["fixed"] => TailwindTableLayout::Fixed.boxed(),
-            // https://tailwindcss.com/docs/display#table
-            [] => TailwindDisplay::Table.boxed(),
             _ => return syntax_error!("Unknown table instructions: {}", str.join("-")),
         };
         Ok(out)
     }
 
-    #[inline]
-    fn object_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match pattern {
-            // https://tailwindcss.com/docs/object-fit
-            ["contain"] => TailwindObjectFit::Contain.boxed(),
-            ["cover"] => TailwindObjectFit::Cover.boxed(),
-            ["fill"] => TailwindObjectFit::Fill.boxed(),
-            ["none"] => TailwindObjectFit::None.boxed(),
-            ["scale", "down"] => TailwindObjectFit::ScaleDown.boxed(),
-            // https://tailwindcss.com/docs/object-position
-            _ => TailwindObjectPosition::parse(pattern, arbitrary)?.boxed(),
-        };
-        Ok(out)
-    }
     #[inline]
     fn overflow_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
@@ -510,57 +450,4 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-
-    #[inline]
-    fn font_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/float
-            [s @ ("sans" | "serif" | "mono")] => TailwindFontFamily::new(s).boxed(),
-            // https://tailwindcss.com/docs/font-size
-            ["xs"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["sm"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["md"] | ["base"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["lg"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["2xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["3xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["4xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["5xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["6xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["7xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["8xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            ["9xl"] => TailwindFontSize::new(0.75, 1.0).boxed(),
-            // https://tailwindcss.com/docs/float
-            ["thin"] => TailwindFontWeight::THIN.boxed(),
-            ["extralight"] => TailwindFontWeight::EXTRA_LIGHT.boxed(),
-            ["light"] => TailwindFontWeight::LIGHT.boxed(),
-            ["normal"] => TailwindFontWeight::NORMAL.boxed(),
-            ["medium"] => TailwindFontWeight::MEDIUM.boxed(),
-            ["semibold"] => TailwindFontWeight::SEMI_BOLD.boxed(),
-            ["bold"] => TailwindFontWeight::BOLD.boxed(),
-            ["extrabold"] => TailwindFontWeight::EXTRA_BOLD.boxed(),
-            ["black"] => TailwindFontWeight::BLACK.boxed(),
-            _ => return syntax_error!("Unknown font instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
-    #[inline]
-    fn text_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/text-align
-            ["left"] => TailwindTextAlignment::Left.boxed(),
-            ["center"] => TailwindTextAlignment::Center.boxed(),
-            ["right"] => TailwindTextAlignment::Right.boxed(),
-            ["justify"] => TailwindTextAlignment::Justify.boxed(),
-            // https://tailwindcss.com/docs/text-color
-            // ["inherit"] => TailwindTextColor::INHERIT.boxed(),
-            // ["current"] => TailwindTextColor::CURRENT.boxed(),
-            // ["transparent"] => TailwindTextColor::TRANSPARENT.boxed(),
-            // ["black"] => TailwindTextColor::BLACK.boxed(),
-            // ["white"] => TailwindTextColor::WHITE.boxed(),
-            // [color, weight] => TailwindTextColor::parse(color, weight)?.boxed(),
-            _ => return syntax_error!("Unknown text instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
 }
